@@ -510,6 +510,8 @@ imapx_expunge_sync (CamelFolder *folder,
 			GPtrArray *known_uids;
 			gint ii;
 
+			camel_folder_summary_lock (folder->summary);
+
 			camel_folder_summary_prepare_fetch_all (folder->summary, NULL);
 			known_uids = camel_folder_summary_get_array (folder->summary);
 
@@ -522,6 +524,8 @@ imapx_expunge_sync (CamelFolder *folder,
 				}
 			}
 
+			camel_folder_summary_unlock (folder->summary);
+
 			camel_folder_summary_free_array (known_uids);
 		}
 
@@ -820,13 +824,17 @@ imapx_refresh_info_sync (CamelFolder *folder,
 	CamelIMAPXServer *imapx_server;
 	CamelIMAPXMailbox *mailbox = NULL;
 	CamelFolderChangeInfo *changes;
-	const gchar *folder_name;
+	gchar *folder_name;
 	gboolean success = FALSE;
 	GError *local_error = NULL;
 
 	store = camel_folder_get_parent_store (folder);
-	folder_name = camel_folder_get_full_name (folder);
 
+	/* Not connected, thus skip the operation */
+	if (!camel_offline_store_get_online (CAMEL_OFFLINE_STORE (store)))
+		return TRUE;
+
+	folder_name = g_strdup (camel_folder_get_full_name (folder));
 	imapx_store = CAMEL_IMAPX_STORE (store);
 	imapx_server = camel_imapx_store_ref_server (imapx_store, folder_name, TRUE, cancellable, error);
 
@@ -870,6 +878,7 @@ imapx_refresh_info_sync (CamelFolder *folder,
 exit:
 	g_clear_object (&mailbox);
 	g_clear_object (&imapx_server);
+	g_free (folder_name);
 
 	return success;
 }
@@ -1078,6 +1087,10 @@ imapx_synchronize_sync (CamelFolder *folder,
 	store = camel_folder_get_parent_store (folder);
 	folder_name = camel_folder_get_full_name (folder);
 
+	/* Not connected, thus skip the operation */
+	if (!camel_offline_store_get_online (CAMEL_OFFLINE_STORE (store)))
+		return TRUE;
+
 	imapx_store = CAMEL_IMAPX_STORE (store);
 	/* while it can be expensive job, do not treat it as such, to avoid a blockage
 	   by really expensive jobs */
