@@ -434,13 +434,6 @@ mbox_store_get_folder_sync (CamelStore *store,
 			folder_name);
 		g_free (name);
 		return NULL;
-	} else if (flags & CAMEL_STORE_FOLDER_EXCL) {
-		g_set_error (
-			error, CAMEL_ERROR, CAMEL_ERROR_GENERIC,
-			_("Cannot create folder '%s': folder exists."),
-			folder_name);
-		g_free (name);
-		return NULL;
 	} else
 		g_free (name);
 
